@@ -11,31 +11,32 @@ known.designs <- function()
 # df2 = degrees of freedom for robust analysis (aka Senn's basic estimator).
 # bk is the so-called design constant, here in terms of total n, 
 # also without carry over.
-# In case of 2x2x4 design Chen, Chow and Liu used bk=1.1 in a model 
-# with carry over.
-# Dec2011 parallel group design now also for n=ntotal
+# In case of 2x2x4 design Chen, Chow and Liu used bk=1.1 (bk(ni)=11/40) 
+#  in a model with carry over.
+# Dec2011: parallel group design now also for n=ntotal
 des <- ("
-no  design    df     df2    steps    bk   bkni
- 0  parallel n-2     n-2      2      4    1           #bkni=???
- 1  2x2      n-2     n-2      2      2    0.5         #bkni=???
- 1  2x2x2    n-2     n-2      2      2    0.5
- 2  3x3      2*n-4   n-3      3      2    NA
- 3  3x6x3    2*n-4   n-6      6      2    NA
- 4  4x4      3*n-6   n-4      4      2    NA
- 5  2x2x3    2*n-3   n-2      2      1.5  0.375       # 3/8
- 6  2x2x4    3*n-4   n-2      2      1    0.25        # 1/4
- 7  2x4x4    3*n-4   n-4      4      1    0.0625      # 1/16
- 9  2x3x3    2*n-3   n-3      3      1.5  0.1666667   # 1/6
-10  2x4x2    n-2     n-2      4      8    0.5
-100 paired   n-1     n-1      1      2    0.5
+no  design    df    df2  steps  bk   bkni
+ 0  parallel n-2    n-2    2    4    1          
+ 1  2x2      n-2    n-2    2    2    0.5        
+ 1  2x2x2    n-2    n-2    2    2    0.5
+ 2  3x3      2*n-4  n-3    3    2    0.22222222 # 2/9   3 sequence latin
+ 3  3x6x3    2*n-4  n-6    6    2    0.05555555 # 1/18  6 sequence 'williams'
+ 4  4x4      3*n-6  n-4    4    2    0.125      # 1/8   4 sequence 'williams'
+ 5  2x2x3    2*n-3  n-2    2    1.5  0.375      # 3/8
+ 6  2x2x4    3*n-4  n-2    2    1    0.25       # 1/4
+ 7  2x4x4    3*n-4  n-4    4    1    0.0625     # 1/16
+ 9  2x3x3    2*n-3  n-3    3    1.5  0.16666667 # 1/6
+10  2x4x2    n-2    n-2    4    8    0.5
+100 paired   n-1    n-1    1    2    0.5
 ")
 # no. 9 is f.i. the partial replicate design TRR/RTR/RRT
 # no. 10 is Balaam's design, a mixture of crossover and parallel group.
-# questionable df2 for Baalams design
+# questionable df2 for Baalams design!
 #
 # eventually it would be better to have steps=6 in case of 3x3 (6 seq. design)
 # Jan 2011: 3x6x3 introduced, df for 3x3 corrected (former 2*n-3)
 # also df for 4x4 corrected (former 3*n-5)
+# Apr-2012: bk(ni) added for 3x3, 3x6x3 and 4x4
   
   des2 <- textConnection(des)
   designs <- read.table(des2, header=TRUE, sep="", strip.white=TRUE, as.is=TRUE)           
